@@ -7,20 +7,22 @@ use warnings;
 use Error::Pure qw(err);
 use Readonly;
 
-Readonly::Array our @EXPORT_OK => qw(check_entity check_property);
+Readonly::Array our @EXPORT_OK => qw(check_entity check_lexeme check_property);
 
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 sub check_entity {
 	my ($self, $key) = @_;
 
-	if (! defined $self->{$key}) {
-		return;
-	}
+	_check_item_with_char($self, $key, 'Q');
 
-	if ($self->{$key} !~ m/^Q\d+$/ms) {
-		err "Parameter '$key' must begin with 'Q' and number after it.";
-	}
+	return;
+}
+
+sub check_lexeme {
+	my ($self, $key) = @_;
+
+	_check_item_with_char($self, $key, 'L');
 
 	return;
 }
@@ -28,12 +30,20 @@ sub check_entity {
 sub check_property {
 	my ($self, $key) = @_;
 
+	_check_item_with_char($self, $key, 'P');
+
+	return;
+}
+
+sub _check_item_with_char {
+	my ($self, $key, $char) = @_;
+
 	if (! defined $self->{$key}) {
 		return;
 	}
 
-	if ($self->{$key} !~ m/^P\d+$/ms) {
-		err "Parameter '$key' must begin with 'P' and number after it.";
+	if ($self->{$key} !~ m/^$char\d+$/ms) {
+		err "Parameter '$key' must begin with '$char' and number after it.";
 	}
 
 	return;
@@ -53,9 +63,10 @@ Wikibase::Datatype::Utils - Wikibase datatype utilities.
 
 =head1 SYNOPSIS
 
- use Wikibase::Datatype::Utils qw(check_entity);
+ use Wikibase::Datatype::Utils qw(check_entity check_lexeme check_property);
 
  check_entity($self, $key);
+ check_lexeme($self, $key);
  check_property($self, $key);
 
 =head1 DESCRIPTION
@@ -72,6 +83,14 @@ Check parameter defined by C<$key> whith is entity (/^Q\d+/).
 
 Returns undef.
 
+=head2 C<check_lexeme>
+
+ check_lexeme($self, $key);
+
+Check parameter defined by C<$key> whith is entity (/^L\d+/).
+
+Returns undef.
+
 =head2 C<check_property>
 
  check_property($self, $key);
@@ -85,6 +104,9 @@ Returns undef.
  check_entity():
          Parameter '%s' must begin with 'Q' and number after it.";
 
+ check_lexeme():
+         Parameter '%s' must begin with 'L' and number after it.";
+
  check_property():
          Parameter '%s' must begin with 'P' and number after it.";
 
@@ -132,6 +154,45 @@ Returns undef.
  use strict;
  use warnings;
 
+ use Wikibase::Datatype::Utils qw(check_lexeme);
+
+ my $self = {
+         'key' => 'L123',
+ };
+ check_lexeme($self, 'key');
+
+ # Print out.
+ print "ok\n";
+
+ # Output:
+ # ok
+
+=head1 EXAMPLE4
+
+ use strict;
+ use warnings;
+
+ use Error::Pure;
+ use Wikibase::Datatype::Utils qw(check_lexeme);
+
+ $Error::Pure::TYPE = 'Error';
+
+ my $self = {
+         'key' => 'bad_entity',
+ };
+ check_lexeme($self, 'key');
+
+ # Print out.
+ print "ok\n";
+
+ # Output like:
+ # #Error [/../Wikibase/Datatype/Utils.pm:?] Parameter 'key' must begin with 'L' and number after it.
+
+=head1 EXAMPLE5
+
+ use strict;
+ use warnings;
+
  use Wikibase::Datatype::Utils qw(check_property);
 
  my $self = {
@@ -145,7 +206,7 @@ Returns undef.
  # Output:
  # ok
 
-=head1 EXAMPLE4
+=head1 EXAMPLE6
 
  use strict;
  use warnings;
@@ -200,6 +261,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
